=======
History
=======

0.4.1 (2022-04-22)
------------------

* Fixed problem with server= vs system= in DSN connection strings


0.2.1 (2020-10-20)
------------------

* Add compilation of mod (%) operator to MOD() function, casting as bigint


0.2.0 (2020-04-02)
------------------

* Warn when i Access driver is not found


0.1.4 (2020-04-01)
------------------

* Fix deployment issue


0.1.2 (2020-04-01)
------------------

* Fix entrypoint definition


0.1.1 (2020-04-01)
------------------

* Remove Python 3.5 from list of supported versions
* Fix deployment issue: correct PYPI key encryption


0.1.0 (2020-04-01)
------------------

* First release on PyPI.
